<?php

namespace Olger\IngVhiculo\Policies;

use Litepie\User\Contracts\UserPolicy;
use Olger\IngVhiculo\Models\Camabaja;

class CamabajaPolicy
{

    /**
     * Determine if the given user can view the camabaja.
     *
     * @param UserPolicy $user
     * @param Camabaja $camabaja
     *
     * @return bool
     */
    public function view(UserPolicy $user, Camabaja $camabaja)
    {
        if ($user->canDo('ing_vhiculo.camabaja.view') && $user->isAdmin()) {
            return true;
        }

        return $camabaja->user_id == user_id() && $camabaja->user_type == user_type();
    }

    /**
     * Determine if the given user can create a camabaja.
     *
     * @param UserPolicy $user
     * @param Camabaja $camabaja
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('ing_vhiculo.camabaja.create');
    }

    /**
     * Determine if the given user can update the given camabaja.
     *
     * @param UserPolicy $user
     * @param Camabaja $camabaja
     *
     * @return bool
     */
    public function update(UserPolicy $user, Camabaja $camabaja)
    {
        if ($user->canDo('ing_vhiculo.camabaja.edit') && $user->isAdmin()) {
            return true;
        }

        return $camabaja->user_id == user_id() && $camabaja->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given camabaja.
     *
     * @param UserPolicy $user
     * @param Camabaja $camabaja
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Camabaja $camabaja)
    {
        return $camabaja->user_id == user_id() && $camabaja->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given camabaja.
     *
     * @param UserPolicy $user
     * @param Camabaja $camabaja
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Camabaja $camabaja)
    {
        if ($user->canDo('ing_vhiculo.camabaja.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given camabaja.
     *
     * @param UserPolicy $user
     * @param Camabaja $camabaja
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Camabaja $camabaja)
    {
        if ($user->canDo('ing_vhiculo.camabaja.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
