<?php

namespace Olger\IngVhiculo\Policies;

use Litepie\User\Contracts\UserPolicy;
use Olger\IngVhiculo\Models\Descuento;

class DescuentoPolicy
{

    /**
     * Determine if the given user can view the descuento.
     *
     * @param UserPolicy $user
     * @param Descuento $descuento
     *
     * @return bool
     */
    public function view(UserPolicy $user, Descuento $descuento)
    {
        if ($user->canDo('ing_vhiculo.descuento.view') && $user->isAdmin()) {
            return true;
        }

        return $descuento->user_id == user_id() && $descuento->user_type == user_type();
    }

    /**
     * Determine if the given user can create a descuento.
     *
     * @param UserPolicy $user
     * @param Descuento $descuento
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('ing_vhiculo.descuento.create');
    }

    /**
     * Determine if the given user can update the given descuento.
     *
     * @param UserPolicy $user
     * @param Descuento $descuento
     *
     * @return bool
     */
    public function update(UserPolicy $user, Descuento $descuento)
    {
        if ($user->canDo('ing_vhiculo.descuento.edit') && $user->isAdmin()) {
            return true;
        }

        return $descuento->user_id == user_id() && $descuento->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given descuento.
     *
     * @param UserPolicy $user
     * @param Descuento $descuento
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Descuento $descuento)
    {
        return $descuento->user_id == user_id() && $descuento->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given descuento.
     *
     * @param UserPolicy $user
     * @param Descuento $descuento
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Descuento $descuento)
    {
        if ($user->canDo('ing_vhiculo.descuento.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given descuento.
     *
     * @param UserPolicy $user
     * @param Descuento $descuento
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Descuento $descuento)
    {
        if ($user->canDo('ing_vhiculo.descuento.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
