<?php

namespace Olger\IngVhiculo\Policies;

use Litepie\User\Contracts\UserPolicy;
use Olger\IngVhiculo\Models\DetalleFacturas;

class DetalleFacturasPolicy
{

    /**
     * Determine if the given user can view the detalle_facturas.
     *
     * @param UserPolicy $user
     * @param DetalleFacturas $detalle_facturas
     *
     * @return bool
     */
    public function view(UserPolicy $user, DetalleFacturas $detalle_facturas)
    {
        if ($user->canDo('ing_vhiculo.detalle_facturas.view') && $user->isAdmin()) {
            return true;
        }

        return $detalle_facturas->user_id == user_id() && $detalle_facturas->user_type == user_type();
    }

    /**
     * Determine if the given user can create a detalle_facturas.
     *
     * @param UserPolicy $user
     * @param DetalleFacturas $detalle_facturas
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('ing_vhiculo.detalle_facturas.create');
    }

    /**
     * Determine if the given user can update the given detalle_facturas.
     *
     * @param UserPolicy $user
     * @param DetalleFacturas $detalle_facturas
     *
     * @return bool
     */
    public function update(UserPolicy $user, DetalleFacturas $detalle_facturas)
    {
        if ($user->canDo('ing_vhiculo.detalle_facturas.edit') && $user->isAdmin()) {
            return true;
        }

        return $detalle_facturas->user_id == user_id() && $detalle_facturas->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given detalle_facturas.
     *
     * @param UserPolicy $user
     * @param DetalleFacturas $detalle_facturas
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, DetalleFacturas $detalle_facturas)
    {
        return $detalle_facturas->user_id == user_id() && $detalle_facturas->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given detalle_facturas.
     *
     * @param UserPolicy $user
     * @param DetalleFacturas $detalle_facturas
     *
     * @return bool
     */
    public function verify(UserPolicy $user, DetalleFacturas $detalle_facturas)
    {
        if ($user->canDo('ing_vhiculo.detalle_facturas.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given detalle_facturas.
     *
     * @param UserPolicy $user
     * @param DetalleFacturas $detalle_facturas
     *
     * @return bool
     */
    public function approve(UserPolicy $user, DetalleFacturas $detalle_facturas)
    {
        if ($user->canDo('ing_vhiculo.detalle_facturas.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
