<?php

namespace Olger\IngVhiculo\Policies;

use Litepie\User\Contracts\UserPolicy;
use Olger\IngVhiculo\Models\Foto;

class FotoPolicy
{

    /**
     * Determine if the given user can view the foto.
     *
     * @param UserPolicy $user
     * @param Foto $foto
     *
     * @return bool
     */
    public function view(UserPolicy $user, Foto $foto)
    {
        if ($user->canDo('ing_vhiculo.foto.view') && $user->isAdmin()) {
            return true;
        }

        return $foto->user_id == user_id() && $foto->user_type == user_type();
    }

    /**
     * Determine if the given user can create a foto.
     *
     * @param UserPolicy $user
     * @param Foto $foto
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('ing_vhiculo.foto.create');
    }

    /**
     * Determine if the given user can update the given foto.
     *
     * @param UserPolicy $user
     * @param Foto $foto
     *
     * @return bool
     */
    public function update(UserPolicy $user, Foto $foto)
    {
        if ($user->canDo('ing_vhiculo.foto.edit') && $user->isAdmin()) {
            return true;
        }

        return $foto->user_id == user_id() && $foto->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given foto.
     *
     * @param UserPolicy $user
     * @param Foto $foto
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Foto $foto)
    {
        return $foto->user_id == user_id() && $foto->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given foto.
     *
     * @param UserPolicy $user
     * @param Foto $foto
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Foto $foto)
    {
        if ($user->canDo('ing_vhiculo.foto.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given foto.
     *
     * @param UserPolicy $user
     * @param Foto $foto
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Foto $foto)
    {
        if ($user->canDo('ing_vhiculo.foto.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
