<?php

namespace Olger\IngVhiculo\Policies;

use Litepie\User\Contracts\UserPolicy;
use Olger\IngVhiculo\Models\IngresoVehiculo;

class IngresoVehiculoPolicy
{

    /**
     * Determine if the given user can view the ingreso_vehiculo.
     *
     * @param UserPolicy $user
     * @param IngresoVehiculo $ingreso_vehiculo
     *
     * @return bool
     */
    public function view(UserPolicy $user, IngresoVehiculo $ingreso_vehiculo)
    {
        if ($user->canDo('ing_vhiculo.ingreso_vehiculo.view') && $user->isAdmin()) {
            return true;
        }

        return $ingreso_vehiculo->user_id == user_id() && $ingreso_vehiculo->user_type == user_type();
    }

    /**
     * Determine if the given user can create a ingreso_vehiculo.
     *
     * @param UserPolicy $user
     * @param IngresoVehiculo $ingreso_vehiculo
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('ing_vhiculo.ingreso_vehiculo.create');
    }

    /**
     * Determine if the given user can update the given ingreso_vehiculo.
     *
     * @param UserPolicy $user
     * @param IngresoVehiculo $ingreso_vehiculo
     *
     * @return bool
     */
    public function update(UserPolicy $user, IngresoVehiculo $ingreso_vehiculo)
    {
        if ($user->canDo('ing_vhiculo.ingreso_vehiculo.edit') && $user->isAdmin()) {
            return true;
        }

        return $ingreso_vehiculo->user_id == user_id() && $ingreso_vehiculo->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given ingreso_vehiculo.
     *
     * @param UserPolicy $user
     * @param IngresoVehiculo $ingreso_vehiculo
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, IngresoVehiculo $ingreso_vehiculo)
    {
        return $ingreso_vehiculo->user_id == user_id() && $ingreso_vehiculo->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given ingreso_vehiculo.
     *
     * @param UserPolicy $user
     * @param IngresoVehiculo $ingreso_vehiculo
     *
     * @return bool
     */
    public function verify(UserPolicy $user, IngresoVehiculo $ingreso_vehiculo)
    {
        if ($user->canDo('ing_vhiculo.ingreso_vehiculo.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given ingreso_vehiculo.
     *
     * @param UserPolicy $user
     * @param IngresoVehiculo $ingreso_vehiculo
     *
     * @return bool
     */
    public function approve(UserPolicy $user, IngresoVehiculo $ingreso_vehiculo)
    {
        if ($user->canDo('ing_vhiculo.ingreso_vehiculo.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
